Documentation
¶
Index ¶
- func AmqpChannel(conf Config) (*amqp.Channel, error)
- func DebugServer(addr string)
- func FailOnError(err error, msg string)
- func LoadCert(path string) (cert []byte, err error)
- func ProfileCmd(profileName string, stats statsd.Statter)
- func RunForever(server *rpc.AmqpRPCServer)
- func RunUntilSignaled(logger *blog.AuditLogger, server *rpc.AmqpRPCServer, ...)
- type AppShell
- type Config
- type Queue
- type TLSConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AmqpChannel ¶
AmqpChannel is the same as amqpConnect in boulder, but with even more aggressive error dropping
func DebugServer ¶
func DebugServer(addr string)
func FailOnError ¶
FailOnError exits and prints an error message if we encountered a problem
func LoadCert ¶
LoadCert loads a PEM-formatted certificate from the provided path, returning it as a byte array, or an error if it couldn't be decoded.
func ProfileCmd ¶
ProfileCmd runs forever, sending Go statistics to StatsD.
func RunForever ¶
func RunForever(server *rpc.AmqpRPCServer)
RunForever starts the server and wait around
func RunUntilSignaled ¶
func RunUntilSignaled(logger *blog.AuditLogger, server *rpc.AmqpRPCServer, closeChan chan *amqp.Error)
RunUntilSignaled starts the server and run until we get something on closeChan
Types ¶
type AppShell ¶
AppShell contains CLI Metadata
func NewAppShell ¶
NewAppShell creates a basic AppShell object containing CLI metadata
func (*AppShell) Run ¶
func (as *AppShell) Run()
Run begins the application context, reading config and passing control to the default commandline action.
func (*AppShell) VersionString ¶
VersionString produces a friendly Application version string
type Config ¶
type Config struct {
ActivityMonitor struct {
// DebugAddr is the address to run the /debug handlers on.
DebugAddr string
}
// General
AMQP struct {
Server string
RA Queue
VA Queue
SA Queue
CA Queue
OCSP Queue
TLS *TLSConfig
}
WFE struct {
BaseURL string
ListenAddress string
CertCacheDuration string
CertNoCacheExpirationWindow string
IndexCacheDuration string
IssuerCacheDuration string
// DebugAddr is the address to run the /debug handlers on.
DebugAddr string
}
CA ca.Config
Monolith struct {
// DebugAddr is the address to run the /debug handlers on.
DebugAddr string
}
RA struct {
// DebugAddr is the address to run the /debug handlers on.
DebugAddr string
}
SA struct {
DBDriver string
DBConnect string
// DebugAddr is the address to run the /debug handlers on.
DebugAddr string
}
VA struct {
UserAgent string
// DebugAddr is the address to run the /debug handlers on.
DebugAddr string
}
SQL struct {
CreateTables bool
SQLDebug bool
}
Statsd struct {
Server string
Prefix string
}
Syslog struct {
Network string
Server string
Tag string
}
Revoker struct {
DBDriver string
DBConnect string
}
Mailer struct {
Server string
Port string
Username string
Password string
DBDriver string
DBConnect string
CertLimit int
NagTimes []string
// Path to a text/template email template
EmailTemplate string
// DebugAddr is the address to run the /debug handlers on.
DebugAddr string
}
OCSPResponder struct {
DBDriver string
DBConnect string
Path string
ListenAddress string
// DebugAddr is the address to run the /debug handlers on.
DebugAddr string
}
OCSPUpdater struct {
DBDriver string
DBConnect string
MinTimeToExpiry string
ResponseLimit int
// DebugAddr is the address to run the /debug handlers on.
DebugAddr string
}
Common struct {
BaseURL string
// Path to a PEM-encoded copy of the issuer certificate.
IssuerCert string
MaxKeySize int
DNSResolver string
DNSTimeout string
}
SubscriberAgreementURL string
}
Config stores configuration parameters that applications will need. For simplicity, we just lump them all into one struct, and use encoding/json to read it from a file.
Note: NO DEFAULTS are provided.